Modules
- prelude
- The prelude exposes the traits for spinners and progress bars, and the
spinner::Spinandprogress::Bartypes for easy access and use. - progress
- silent
- A silent progress bar and spinner that does nothing.
- spinner
- A simple character spinner for bars with no known size
- wheel
- Contains infinite
chariterators and the type wrapping them,Wheel.
Traits
- Display
- A trait for all bars’ displaying
- Progress
Bar - A trait for any bar with progress. You can implemnent your own styles through this trait.
- Spinner
- A trait for any bar without progress. You can implemnent your own styles through this trait.
- With
Title - A trait for creating a progress bar or spinner with a title.
Functions
- has_
terminal_ output - Returns true if
fhas a terminal output and can be used with terminal size responsiveness. - has_
terminal_ output_ default - Returns true if
stdouthas a terminal output and can be used with terminal size responsiveness.