MaybeSilent

Enum MaybeSilent 

pub enum MaybeSilent<T> {
    Silent,
    Loud(T),
}
An enum wrapper for a progress bar or spinner that might be silent.

Variants



Silent

There is no progress



Loud(T)

There is progress

Implementations

Source

impl<T> MaybeSilent<T>

pub fn is_loud(&self) -> bool

Is this the not silent variant?

pub fn is_silent(&self) -> bool

Is this the silent variant?

pub const fn new_some(value: T) -> Self

Create a new MaybeSilent with a value.

pub fn new<U>(from: U) -> Self
where U: Into<Option<T>>,

Create a new MaybeSilent with a potential value

pub fn as_ref(&self) -> Option<&T>

Get a reference to the inner type if possible

pub fn as_mut(&mut self) -> Option<&mut T>

Get a mutable reference to the inner type if possible

pub fn as_display_mut(&mut self) -> Option<&mut (dyn Display + 'static)>
where T: Display + 'static,

Get a dynamic mutable reference to the internal value if it is Display.

pub fn into_inner(self) -> Option<T>

Consume this instance and return the inner value if possible

pub fn into_silent(self) -> Option<Silent>

Consume this instance and return silent if it had no value

pub fn as_bar_mut(&mut self) -> Option<&mut (dyn ProgressBar + 'static)>
where T: ProgressBar + 'static,

Get a dynamic mutable reference to the internal value if it is ProgressBar

pub fn as_spinner_mut(&mut self) -> Option<&mut (dyn Spinner + 'static)>
where T: Spinner + 'static,

Get a dynamic mutable reference to the internal value if it is Spinner.

pub fn as_display(&self) -> Option<&(dyn Display + 'static)>
where T: Display + 'static,

Get a dynamic reference to the internal value if it is Display.

pub fn as_bar(&self) -> Option<&(dyn ProgressBar + 'static)>
where T: ProgressBar + 'static,

Get a dynamic reference to the internal value if it is ProgressBar

pub fn as_spinner(&self) -> Option<&(dyn Spinner + 'static)>
where T: Spinner + 'static,

Get a dynamic reference to the internal value if it is Spinner.