pub enum MaybeSilent<T> {
Silent,
Loud(T),
}Expand description
An enum wrapper for a progress bar or spinner that might be silent.
Variants
Implementations
Sourceimpl<T> MaybeSilent<T>
impl<T> MaybeSilent<T>
Sourcepub fn as_mut(&mut self) -> Option<&mut T>
pub fn as_mut(&mut self) -> Option<&mut T>
Get a mutable reference to the inner type if possible
Sourcepub fn as_display_mut(&mut self) -> Option<&mut (dyn Display + 'static)>where
T: Display + 'static,
pub fn as_display_mut(&mut self) -> Option<&mut (dyn Display + 'static)>where
T: Display + 'static,
Get a dynamic mutable reference to the internal value if it is Display.
Sourcepub fn into_inner(self) -> Option<T>
pub fn into_inner(self) -> Option<T>
Consume this instance and return the inner value if possible
Sourcepub fn into_silent(self) -> Option<Silent>
pub fn into_silent(self) -> Option<Silent>
Consume this instance and return silent if it had no value
Sourcepub fn as_bar_mut(&mut self) -> Option<&mut (dyn ProgressBar + 'static)>where
T: ProgressBar + 'static,
pub fn as_bar_mut(&mut self) -> Option<&mut (dyn ProgressBar + 'static)>where
T: ProgressBar + 'static,
Get a dynamic mutable reference to the internal value if it is ProgressBar
Sourcepub fn as_spinner_mut(&mut self) -> Option<&mut (dyn Spinner + 'static)>where
T: Spinner + 'static,
pub fn as_spinner_mut(&mut self) -> Option<&mut (dyn Spinner + 'static)>where
T: Spinner + 'static,
Get a dynamic mutable reference to the internal value if it is Spinner.
Sourcepub fn as_display(&self) -> Option<&(dyn Display + 'static)>where
T: Display + 'static,
pub fn as_display(&self) -> Option<&(dyn Display + 'static)>where
T: Display + 'static,
Get a dynamic reference to the internal value if it is Display.
Sourcepub fn as_bar(&self) -> Option<&(dyn ProgressBar + 'static)>where
T: ProgressBar + 'static,
pub fn as_bar(&self) -> Option<&(dyn ProgressBar + 'static)>where
T: ProgressBar + 'static,
Get a dynamic reference to the internal value if it is ProgressBar
Sourcepub fn as_spinner(&self) -> Option<&(dyn Spinner + 'static)>where
T: Spinner + 'static,
pub fn as_spinner(&self) -> Option<&(dyn Spinner + 'static)>where
T: Spinner + 'static,
Get a dynamic reference to the internal value if it is Spinner.